#!/usr/bin/env python3
"""
Setup script for intelliheal-pytest.

This setup.py exists for compatibility with tools that don't yet support
PEP 621 (pyproject.toml). All configuration is in pyproject.toml.
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
